import {
  clear, printProjectVersion, successLog, torderLog, printProjectCopyFinish, printAlreadyDir,
} from './utils/console.js';
import PackageManager from './packageManager.js';
import copy from './utils/file.js';
import selectOptions from './utils/prompt.js';
import DEFAULT_TEMPLATE from './utils/string.js';
import runTransCode from './jscodeshift/main.js';
import addModules from './utils/option.js';
import { checkDir, setGlobals } from './utils/common.js';

async function create(projectName) {
  clear();
  if (!checkDir(projectName)) {
    printAlreadyDir(projectName);
    process.exit(1);
  }
  const selectedOptions = await selectOptions(projectName);
  setGlobals(projectName, selectedOptions);
  await copy(DEFAULT_TEMPLATE, projectName);
  await runTransCode(projectName, selectedOptions);
  clear();
  printProjectVersion();
  torderLog();
  printProjectCopyFinish();
  const packageManager = PackageManager;
  packageManager.init(projectName);
  packageManager.addModules(selectedOptions);
  await addModules(projectName, selectedOptions);
  await packageManager.install();
  successLog(projectName);
}

export default create;
