import chalk from 'chalk';
import figlet from 'figlet';
import { readFileSync } from 'fs';
import globals from '../global.js';
import { dirName } from './path.js';

const { log } = console;

export const torderLog = () => {
  log(figlet.textSync('T VUE CLI'));
};

export const successLog = (projectName) => {
  log(`🎉 ${chalk.green('Successfully')} ${chalk.whiteBright('created project')} ${chalk.yellow(projectName)}`);
};

export const projectNameEmptyLog = () => {
  log(`❗ ${chalk.red('Project name is empty')}\n${chalk.yellow('Usage: t-vue <project-name>')}`);
};

export const printProjectVersion = () => {
  const json = JSON.parse(readFileSync(new URL('../../package.json', import.meta.url)));
  log(chalk.blueBright(`T-VUE CLI v${json.version}`));
};

export const printProjectCopyFinish = () => {
  log(`✨ Creating project in ${dirName}/${globals.projectName}`);
};

export const printGitInit = () => {
  log('🗃  Initializing git repository');
};

export const printYarnInstall = () => {
  log(chalk.whiteBright('yarn install'));
};

export const printAlreadyDir = (projectPath) => {
  log(`🚫 ${projectPath} directory already exists`);
};

export const clear = () => {
  console.clear();
};
